@@ -70,6 +70,8 @@
 //! To directly construct from `iron::status::StatusCode` from the [iron-framework](http://ironframework.io/)
 //! use `feature` `iron` which adds `From<iron::status::StatusCode> for HttpStatusCode`.
 //!
+//! Ther `serde` feature provides `Serialize` and `Deserialize` for `HttpStatusCode`.
+//!
 //! ## License
 //!
 //! `http-api-problem` is primarily distributed under the terms of both the MIT license and the
@@ -77,9 +79,9 @@
 //!
 //! Copyright (c) 2017 Christian Douven.
 
-extern crate serde;
+#[cfg(feature = "serde")]
 #[macro_use]
-extern crate serde_derive;
+extern crate serde;
 
 #[cfg(feature = "iron")]
 extern crate iron;
@@ -105,7 +107,8 @@ pub static PROBLEM_XML_MEDIA_TYPE: &'static str = "application/problem+xml";
 ///    "instance": "/account/12345/msgs/abc",
 /// }
 /// ```
-#[derive(Debug, Clone, Serialize, Deserialize)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+#[derive(Debug, Clone)]
 pub struct HttpApiProblem {
     /// A URI reference [RFC3986](https://tools.ietf.org/html/rfc3986) that identifies the
     /// problem type.  This specification encourages that, when
@@ -113,12 +116,12 @@ pub struct HttpApiProblem {
     /// problem type (e.g., using HTML [W3C.REC-html5-20141028]).  When
     /// this member is not present, its value is assumed to be
     /// "about:blank".
-    #[serde(rename = "type")]
-    #[serde(skip_serializing_if = "Option::is_none")]
+    #[cfg_attr(feature = "serde", serde(rename = "type"))]
+    #[cfg_attr(feature = "serde", serde(skip_serializing_if = "Option::is_none"))]
     pub type_url: Option<String>,
     /// The HTTP status code [RFC7231, Section 6](https://tools.ietf.org/html/rfc7231#section-6)
     /// generated by the origin server for this occurrence of the problem.
-    #[serde(skip_serializing_if = "Option::is_none")]
+    #[cfg_attr(feature = "serde", serde(skip_serializing_if = "Option::is_none"))]
     pub status: Option<u16>,
     /// A short, human-readable summary of the problem
     /// type. It SHOULD NOT change from occurrence to occurrence of the
@@ -130,12 +133,12 @@ pub struct HttpApiProblem {
     pub title: String,
     /// A human-readable explanation specific to this
     /// occurrence of the problem.
-    #[serde(skip_serializing_if = "Option::is_none")]
+    #[cfg_attr(feature = "serde", serde(skip_serializing_if = "Option::is_none"))]
     pub detail: Option<String>,
     /// A URI reference that identifies the specific
     /// occurrence of the problem.  It may or may not yield further
     /// information if dereferenced.
-    #[serde(skip_serializing_if = "Option::is_none")]
+    #[cfg_attr(feature = "serde", serde(skip_serializing_if = "Option::is_none"))]
     pub instance: Option<String>,
 }
 
@@ -417,7 +420,7 @@ pub enum HttpStatusCode {
 }
 
 impl HttpStatusCode {
-    /// A descriptice title for the status code which does not contain
+    /// A descriptive title for the status code which does not contain
     /// the numeric code itself.
     ///
     /// #Example
